mirror of
https://github.com/gentoo-mirror/gentoo.git
synced 2026-09-24 17:09:10 -07:00
sci-libs/flann: remove unused patch(es)
This commit is contained in:
committed by
Aaron Bauman
parent
93157bb277
commit
f09934d575
@@ -1,16 +0,0 @@
|
||||
src/cpp/CMakeLists.txt | 2 +-
|
||||
1 file changed, 1 insertion(+), 1 deletion(-)
|
||||
|
||||
diff --git a/src/cpp/CMakeLists.txt b/src/cpp/CMakeLists.txt
|
||||
index 8e72409..a4b35b1 100644
|
||||
--- a/src/cpp/CMakeLists.txt
|
||||
+++ b/src/cpp/CMakeLists.txt
|
||||
@@ -15,7 +15,7 @@ endif()
|
||||
set_property(TARGET flann_cpp_s PROPERTY COMPILE_DEFINITIONS FLANN_STATIC FLANN_USE_CUDA)
|
||||
|
||||
if (BUILD_CUDA_LIB)
|
||||
- SET(CUDA_NVCC_FLAGS -DFLANN_USE_CUDA)
|
||||
+ SET(CUDA_NVCC_FLAGS "${CUDA_NVCC_FLAGS};-DFLANN_USE_CUDA")
|
||||
if(CMAKE_COMPILER_IS_GNUCC)
|
||||
set(CUDA_NVCC_FLAGS "${CUDA_NVCC_FLAGS};-Xcompiler;-fPIC;-arch=sm_13" )
|
||||
if (NVCC_COMPILER_BINDIR)
|
||||
@@ -1,61 +0,0 @@
|
||||
src/cpp/flann/util/cuda/result_set.h | 12 ++++++------
|
||||
1 file changed, 6 insertions(+), 6 deletions(-)
|
||||
|
||||
diff --git a/src/cpp/flann/util/cuda/result_set.h b/src/cpp/flann/util/cuda/result_set.h
|
||||
index 9ac8111..324ca1e 100644
|
||||
--- a/src/cpp/flann/util/cuda/result_set.h
|
||||
+++ b/src/cpp/flann/util/cuda/result_set.h
|
||||
@@ -54,7 +54,7 @@ struct SingleResultSet
|
||||
DistanceType bestDist;
|
||||
const DistanceType epsError;
|
||||
|
||||
- __device__
|
||||
+ __device__ __host__
|
||||
SingleResultSet( DistanceType eps ) : bestIndex(-1),bestDist(INFINITY), epsError(eps){ }
|
||||
|
||||
__device__
|
||||
@@ -129,7 +129,7 @@ struct KnnResultSet
|
||||
const DistanceType epsError;
|
||||
|
||||
|
||||
- __device__
|
||||
+ __device__ __host__
|
||||
KnnResultSet(int knn, bool sortResults, DistanceType eps) : foundNeighbors(0),largestHeapDist(INFINITY),k(knn), sorted(sortResults), epsError(eps){ }
|
||||
|
||||
// __host__ __device__
|
||||
@@ -229,7 +229,7 @@ struct CountingRadiusResultSet
|
||||
DistanceType radius_sq_;
|
||||
int max_neighbors_;
|
||||
|
||||
- __device__
|
||||
+ __device__ __host__
|
||||
CountingRadiusResultSet(DistanceType radius, int max_neighbors) : count_(0),radius_sq_(radius), max_neighbors_(max_neighbors){ }
|
||||
|
||||
__device__
|
||||
@@ -279,7 +279,7 @@ struct RadiusKnnResultSet
|
||||
// int count_;
|
||||
|
||||
|
||||
- __device__
|
||||
+ __device__ __host__
|
||||
RadiusKnnResultSet(DistanceType radius, int knn, int* segment_starts, bool sortResults) : foundNeighbors(0),largestHeapDist(radius),k(knn), sorted(sortResults), radius_sq_(radius),segment_starts_(segment_starts) { }
|
||||
|
||||
// __host__ __device__
|
||||
@@ -381,7 +381,7 @@ struct KnnRadiusResultSet
|
||||
const DistanceType radius_sq;
|
||||
|
||||
|
||||
- __device__
|
||||
+ __device__ __host__
|
||||
KnnRadiusResultSet(int knn, bool sortResults, DistanceType eps, DistanceType radius) : foundNeighbors(0),largestHeapDist(radius),k(knn), sorted(sortResults), epsError(eps),radius_sq(radius){ }
|
||||
|
||||
// __host__ __device__
|
||||
@@ -484,7 +484,7 @@ struct RadiusResultSet
|
||||
int count_;
|
||||
bool sorted_;
|
||||
|
||||
- __device__
|
||||
+ __device__ __host__
|
||||
RadiusResultSet(DistanceType radius, int* segment_starts, bool sorted) : radius_sq_(radius), segment_starts_(segment_starts), count_(0), sorted_(sorted){ }
|
||||
|
||||
__device__
|
||||
@@ -1,24 +0,0 @@
|
||||
doc/CMakeLists.txt | 6 +++++-
|
||||
1 file changed, 5 insertions(+), 1 deletion(-)
|
||||
|
||||
diff --git a/doc/CMakeLists.txt b/doc/CMakeLists.txt
|
||||
index 2d8eb24..aeac8ed 100644
|
||||
--- a/doc/CMakeLists.txt
|
||||
+++ b/doc/CMakeLists.txt
|
||||
@@ -1,4 +1,8 @@
|
||||
find_package(LATEX)
|
||||
+
|
||||
+if (NOT DOCDIR)
|
||||
+ set(DOCDIR share/doc/flann)
|
||||
+endif ()
|
||||
|
||||
if (EXISTS ${PDFLATEX_COMPILER} AND EXISTS ${BIBTEX_COMPILER})
|
||||
include(${PROJECT_SOURCE_DIR}/cmake/UseLATEX.cmake)
|
||||
@@ -14,6 +18,6 @@ endif()
|
||||
|
||||
install(
|
||||
FILES manual.pdf
|
||||
- DESTINATION share/doc/flann
|
||||
+ DESTINATION ${DOCDIR}
|
||||
OPTIONAL
|
||||
)
|
||||
@@ -1,35 +0,0 @@
|
||||
From 3922081fbd6710f4b72421069f6bf24dc37d35a8 Mon Sep 17 00:00:00 2001
|
||||
From: Casey Goodlett <casey.goodlett@kitware.com>
|
||||
Date: Thu, 8 Aug 2013 18:42:45 -0400
|
||||
Subject: [PATCH] Option to disable example building
|
||||
|
||||
---
|
||||
CMakeLists.txt | 5 ++++-
|
||||
1 file changed, 4 insertions(+), 1 deletion(-)
|
||||
|
||||
diff --git a/CMakeLists.txt b/CMakeLists.txt
|
||||
index 5b19367..410a8f9 100644
|
||||
--- a/CMakeLists.txt
|
||||
+++ b/CMakeLists.txt
|
||||
@@ -53,6 +53,7 @@ option(BUILD_C_BINDINGS "Build C bindings" ON)
|
||||
option(BUILD_PYTHON_BINDINGS "Build Python bindings" ON)
|
||||
option(BUILD_MATLAB_BINDINGS "Build Matlab bindings" ON)
|
||||
option(BUILD_CUDA_LIB "Build CUDA library" OFF)
|
||||
+option(BUILD_EXAMPLES "Build examples" ON)
|
||||
option(USE_OPENMP "Use OpenMP multi-threading" ON)
|
||||
option(USE_MPI "Use MPI" OFF)
|
||||
|
||||
@@ -154,7 +155,9 @@ endif()
|
||||
|
||||
add_subdirectory( cmake )
|
||||
add_subdirectory( src )
|
||||
-add_subdirectory( examples )
|
||||
+if (BUILD_EXAMPLES)
|
||||
+ add_subdirectory( examples )
|
||||
+endif(BUILD_EXAMPLES)
|
||||
add_subdirectory( test )
|
||||
add_subdirectory( doc )
|
||||
|
||||
--
|
||||
1.8.5.1
|
||||
|
||||
@@ -1,15 +0,0 @@
|
||||
cmake/flann_utils.cmake | 2 +-
|
||||
1 file changed, 1 insertion(+), 1 deletion(-)
|
||||
|
||||
diff --git a/cmake/flann_utils.cmake b/cmake/flann_utils.cmake
|
||||
index 1a10939..afe4742 100644
|
||||
--- a/cmake/flann_utils.cmake
|
||||
+++ b/cmake/flann_utils.cmake
|
||||
@@ -1,6 +1,6 @@
|
||||
macro(GET_OS_INFO)
|
||||
string(REGEX MATCH "Linux" OS_IS_LINUX ${CMAKE_SYSTEM_NAME})
|
||||
- set(FLANN_LIB_INSTALL_DIR "lib")
|
||||
+ set(FLANN_LIB_INSTALL_DIR "lib${LIB_SUFFIX}")
|
||||
set(FLANN_INCLUDE_INSTALL_DIR
|
||||
"include/${PROJECT_NAME_LOWER}-${FLANN_MAJOR_VERSION}.${FLANN_MINOR_VERSION}")
|
||||
endmacro(GET_OS_INFO)
|
||||
@@ -1,41 +0,0 @@
|
||||
CMakeLists.txt | 13 +++++++++++--
|
||||
1 file changed, 11 insertions(+), 2 deletions(-)
|
||||
|
||||
diff --git a/CMakeLists.txt b/CMakeLists.txt
|
||||
index 410a8f9..b6244a4 100644
|
||||
--- a/CMakeLists.txt
|
||||
+++ b/CMakeLists.txt
|
||||
@@ -54,6 +54,8 @@ option(BUILD_PYTHON_BINDINGS "Build Python bindings" ON)
|
||||
option(BUILD_MATLAB_BINDINGS "Build Matlab bindings" ON)
|
||||
option(BUILD_CUDA_LIB "Build CUDA library" OFF)
|
||||
option(BUILD_EXAMPLES "Build examples" ON)
|
||||
+option(BUILD_TESTS "Build tests" ON)
|
||||
+option(BUILD_DOC "Build documentation" ON)
|
||||
option(USE_OPENMP "Use OpenMP multi-threading" ON)
|
||||
option(USE_MPI "Use MPI" OFF)
|
||||
|
||||
@@ -158,8 +160,12 @@ add_subdirectory( src )
|
||||
if (BUILD_EXAMPLES)
|
||||
add_subdirectory( examples )
|
||||
endif(BUILD_EXAMPLES)
|
||||
-add_subdirectory( test )
|
||||
-add_subdirectory( doc )
|
||||
+if (BUILD_TESTS)
|
||||
+ add_subdirectory( test )
|
||||
+endif (BUILD_TESTS)
|
||||
+if (BUILD_DOC)
|
||||
+ add_subdirectory( doc )
|
||||
+endif (BUILD_DOC)
|
||||
|
||||
|
||||
# CPACK options
|
||||
@@ -202,6 +208,9 @@ include(CPack)
|
||||
message(STATUS "Install prefix: ${CMAKE_INSTALL_PREFIX}")
|
||||
message(STATUS "Build type: ${CMAKE_BUILD_TYPE}")
|
||||
message(STATUS "Building C bindings: ${BUILD_C_BINDINGS}")
|
||||
+message(STATUS "Building examples: ${BUILD_EXAMPLES}")
|
||||
+message(STATUS "Building tests: ${BUILD_TESTS}")
|
||||
+message(STATUS "Building documentation: ${BUILD_DOC}")
|
||||
message(STATUS "Building python bindings: ${BUILD_PYTHON_BINDINGS}")
|
||||
message(STATUS "Building matlab bindings: ${BUILD_MATLAB_BINDINGS}")
|
||||
message(STATUS "Building CUDA library: ${BUILD_CUDA_LIB}")
|
||||
Reference in New Issue
Block a user